==> mx-welcome_19.6.tar.xz: mx-welcome/translations/mx-welcome_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation>Debe ejecutar este programa como un usuario normal.</translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="../mxwelcome.ui" line="14"/>
        <location filename="../mxwelcome.cpp" line="54"/>
        <location filename="../mxwelcome.cpp" line="99"/>
        <location filename="../mxwelcome.cpp" line="111"/>
        <source>MX Welcome</source>
        <translation>MX Welcome</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Bienvenidos a MX Linux, un Sistema Operativo veloz, amigable y estable, cargado con herramientas asombrosas; todo apoyado por una gran comunidad. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="113"/>
        <source>Popular Apps</source>
        <translation>Aps Populares</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="203"/>
        <source>Forums</source>
        <translation>Foros</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="280"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="377"/>
        <source>Contribute</source>
        <translation>Contribuir</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Retocar (Panel, etcétera,...)</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="486"/>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="512"/>
        <source>Codecs</source>
        <translation>Códecs</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="544"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="576"/>
        <source>Users Manual</source>
        <translation>Manual del Usuario</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="608"/>
        <source>FAQ</source>
        <translation>PP. FF. (Preguntas frecuentes)</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="641"/>
        <source>Show this dialog at start up</source>
        <translation>Mostrar esta ventana al inicio</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="706"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="709"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="716"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="770"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="773"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="780"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="57"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation>Usuario predeterminado:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Clave predeterminada:  &lt;b&gt;demo&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="58"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;b&gt;Root&lt;/b&gt; Clave:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="98"/>
        <source>About MX Welcome</source>
        <translation>Acerca de MX Bienvenida</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="99"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="100"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programa para desplegar una pantalla de bienvenida en MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="102"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="103"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="104"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="105"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="121"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>

==> mx-welcome_19.8.02.tar.xz: mx-welcome/translations/mx-welcome_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation>Debe ejecutar este programa como un usuario normal.</translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="mxwelcome.ui" line="14"/>
        <location filename="mxwelcome.cpp" line="54"/>
        <location filename="mxwelcome.cpp" line="99"/>
        <location filename="mxwelcome.cpp" line="111"/>
        <source>MX Welcome</source>
        <translation>MX Welcome</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Bienvenidos a MX Linux, un Sistema Operativo veloz, amigable y estable, cargado con herramientas asombrosas; todo apoyado por una gran comunidad. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="113"/>
        <source>Popular Apps</source>
        <translation>Aps Populares</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="203"/>
        <source>Forums</source>
        <translation>Foros</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="280"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="377"/>
        <source>Contribute</source>
        <translation>Contribuir</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Retocar (Panel, etcétera,...)</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="486"/>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="512"/>
        <source>Codecs</source>
        <translation>Códecs</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="544"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="576"/>
        <source>Users Manual</source>
        <translation>Manual del Usuario</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="608"/>
        <source>FAQ</source>
        <translation>PP. FF. (Preguntas frecuentes)</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="641"/>
        <source>Show this dialog at start up</source>
        <translation>Mostrar esta ventana al inicio</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="706"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="709"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="716"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="770"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="773"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="mxwelcome.ui" line="780"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="57"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation>Usuario predeterminado:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Clave predeterminada:  &lt;b&gt;demo&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="58"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;b&gt;Root&lt;/b&gt; Clave:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="98"/>
        <source>About MX Welcome</source>
        <translation>Acerca de MX Bienvenida</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="99"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="100"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programa para desplegar una pantalla de bienvenida en MX Linux</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="102"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="103"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="104"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="105"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="mxwelcome.cpp" line="121"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>
